Credits
=======

We would like to thank `Andrew Godwin <https://github.com/andrewgodwin>`_,
along with the `Django Software Foundation <https://www.djangoproject.com/foundation/>`_,
for providing the wonderful and easy-to-use `Django Channels <channels.readthedocs.io>`_
framework to base our websocket-based app on. 
